# $File: //depot/OurNet-BBS/BBS/MELIX/UserGroup.pm $ $Author: autrijus $
# $Revision: #4 $ $Change: 1525 $ $DateTime: 2001/08/17 22:49:33 $

package OurNet::BBS::MELIX::UserGroup;

use base qw/OurNet::BBS::MAPLE3::UserGroup/;
use fields qw/_ego _hash _array/;

use OurNet::BBS::Base;

1;
